package demoInputValidation;

import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;

/**
 * This class implements controller behaviour for the application.
 * 
 * It receives requests (from the end user) and passes them to the model and/or
 * the view via method invocation
 * 
 */
public class FocusBasedController implements FocusListener {
	private ViewExplicitController view;
	private MyPlainDocument model;

	/*
	 * Creates a controller for the given view and model. @param view the view
	 * of the GUI. @param model the model of the GUI.
	 */
	public FocusBasedController(ViewExplicitController view, MyPlainDocument model) {
		this.view = view;
		this.model = model;
	}

	public void focusGained(FocusEvent fe) {
	}

	public void focusLost(FocusEvent fe) {
		if (fe.getSource() == view.getNumericField()) {
			String s = view.getNumericField().getText();
			if (s.length() != 0) {
				try {
					Integer.parseInt(s);
				} catch (NumberFormatException nfe) {
					view.getToolkit().beep();
					view.getNumericField().requestFocus();
				}
			}
		} else if (fe.getSource() == view.getAlphaField()) {
			String s = view.getAlphaField().getText();
			if (s.length() != 0) {
				if (!containsLettersOnly(s)) {
					view.getToolkit().beep();
					view.getAlphaField().requestFocus();
				}
			}
		}
	}

	private boolean containsLettersOnly(String sArg) {
		for (int i = 0; i < sArg.length(); ++i)
			if (!Character.isLetter(sArg.charAt(i)))
				return false;
		return true;
	}

}
