package demoInputValidation;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;


/**
 * This class implements controller behaviour for the application.
 * 
 * It receives requests (from the end user) and passes them to the model and/or
 * the view via method invocation
 * 
 */
public class KeyEventBasedController implements KeyListener {
	private ViewExplicitController view;
	private MyPlainDocument model;

	/*
	 * Creates a controller for the given view and model. @param view the view
	 * of the GUI. @param model the model of the GUI.
	 */
	public KeyEventBasedController(ViewExplicitController view, MyPlainDocument model) {
		this.view = view;
		this.model = model;
	}

	public void keyPressed(KeyEvent ke) {
	}

	public void keyReleased(KeyEvent ke) {
	}

	public void keyTyped(KeyEvent ke) {
		if (ke.getSource() == view.getNumericField()) {
			char c = ke.getKeyChar();
			if (c == KeyEvent.VK_BACK_SPACE || c == KeyEvent.VK_DELETE) {
				// we will accept BACK_SPACE and DELETE, so don't intercede
			} else if (!Character.isDigit(c)) {
				// we will accept an digit in the numeric field, so don't
				// intercede
				view.getToolkit().beep();
				ke.consume();
			} else {
				// need to ensure that the entire contents of the field is an
				// integer
				// e.g., if too many digits are entered, then number might
				// exceed maximum integer
				String s = view.getNumericField().getText();
				if (s.length() != 0) {
					try {
						Integer.parseInt(s);
					} catch (NumberFormatException nfe) {
						view.getToolkit().beep();
						ke.consume();
					}
				}
			}
		} else if (ke.getSource() == view.getAlphaField()) {
			char c = ke.getKeyChar();
			if (c == KeyEvent.VK_BACK_SPACE || c == KeyEvent.VK_DELETE) {
				// we will accept BACK_SPACE and DELETE, so don't intercede
			} else if (!Character.isLetter(c)) {
				view.getToolkit().beep();
				ke.consume();
			}
		}
	}

}
